@@ -9,11 +9,19 @@
 setMethod( "show" , "hash" ,
 	function(object) {
 		cat( 
-			paste( 
-				"An object of type 'hash' containing",
-				length( object ) ,
-				"key-value pairs.\n"
-			)
+		  "An object of type 'hash' containing",
+		  length( object ) ,
+		  "key-value pairs.\n" 
 		)
+
+        for ( k in keys(object)  ) 
+           cat( 
+             " ", 
+             k , 
+             ": " , 
+             as.character(object[[k]]), 
+             "\n" 
+           )
+
 	}
 ) 
